@@ -1,9 +1,8 @@
 package WWW::Vimeo::Simple::Album;
-BEGIN {
-  $WWW::Vimeo::Simple::Album::VERSION = '0.06';
+{
+  $WWW::Vimeo::Simple::Album::VERSION = '0.07';
 }
 
-use Carp;
 use JSON;
 use Moose;
 use HTTP::Tiny;
@@ -20,7 +19,7 @@ WWW::Vimeo::Simple::Album - Album requests for the Vimeo Simple API
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -250,7 +249,7 @@ sub _make_url {
 
 =head1 AUTHOR
 
-Alessandro Ghedini, C<< <alexbio at cpan.org> >>
+Alessandro Ghedini <alexbio@cpan.org>
 
 =head1 LICENSE AND COPYRIGHT
 
@@ -264,4 +263,4 @@ See http://dev.perl.org/licenses/ for more information.
 
 =cut
 
-1; # End of WWW::Vimeo::Simple::Album
\ No newline at end of file
+1; # End of WWW::Vimeo::Simple::Album
